import { select } from 'd3';
import { viz } from './viz';
import { data } from '@curran/daily-surface-air-temperature';
import { observeResize } from '@curran/responsive-axes';

// {
//   "day_of_year": 1,
//   "year": 1940,
//   "value": "11.721",
//   "airTemp": 11.721
// }

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  viz(svg, {
    data,
    xValue: (d) => d.day_of_year,
    xAxisLabelText: 'Day of Year',
    xAxisLabelOffset: 38,
    yValue: (d) => d.airTemp,
    lineValue: (d) => d.year,
    yAxisLabelText: 'Air Temperature',
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    lineOpacity: 416 / 1000,
    marginTop: 20,
    marginBottom: 50,
    marginLeft: 54,
    marginRight: 20,
    width,
    height,
  });
};
