import {
  scaleLinear,
  scaleSequential,
  axisLeft,
  extent,
  line,
  flatGroup,
  interpolatePlasma,
} from 'd3';
import { axes } from '@curran/responsive-axes';

export const viz = (
  svg,
  {
    data,
    xValue,
    xAxisLabelText,
    xAxisLabelOffset,
    yValue,
    yAxisLabelText,
    yAxisLabelOffset,
    lineValue,
    marginLeft,
    marginTop,
    marginRight,
    marginBottom,
    width,
    height,
    innerRectFill,
    lineOpacity,
  },
) => {
  const xScale = scaleLinear(extent(data, xValue), [
    marginLeft,
    width - marginRight,
  ]);
  const yScale = scaleLinear(extent(data, yValue), [
    height - marginBottom,
    marginTop,
  ]);

  const colorScale = scaleSequential(
    extent(data, lineValue).reverse(),
    interpolatePlasma,
  );

  const innerWidth = width - marginLeft - marginRight;
  const innerHeight = height - marginTop - marginBottom;

  axes(svg, {
    width,
    height,
    xScale,
    xAxisLabelText,
    xAxisLabelOffset,
    yScale,
    yAxisLabelText,
    yAxisLabelOffset,
    marginLeft,
    marginBottom,
  });

  const lineGenerator = line(
    (d) => xScale(xValue(d)),
    (d) => yScale(yValue(d)),
  ).defined(yValue);

  const dataGrouped = flatGroup(data, lineValue);

  // Multiple lines, one for each group
  svg
    .selectAll('path.mark')
    .data(dataGrouped)
    .join('path')
    .attr('class', 'mark')
    .attr('fill', 'none')
    .attr('stroke-linecap', 'round')
    .attr('stroke', 'black')
    .attr('opacity', (d) =>
      d[0] === 2024 ? 1 : lineOpacity,
    )
    .attr('stroke-width', (d) => {
      if (d[0] === 2024) return 6;
      return 1;
    })
    .attr('stroke', (d) => {
      // `d` here has the following structure:
      // [year, arrayOfValues[]]
      if (d[0] === 2024) return 'red';
      return colorScale(d[0]);
    })
    .attr('d', (d) => lineGenerator(d[1]));
};
